@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # autogen.sh glue for pslib
-# $Id: autogen.sh,v 1.6 2007/10/30 07:37:24 steinm Exp $
+# $Id$
 #
 # Requires: automake, autoconf, dpkg-dev
 set -e
@@ -35,7 +35,7 @@ test -d debian && {
 	# for whatever reason.
 	echo Generating list of executable files...
 	rm -f debian/executable.files
-	find -type f -perm +111 ! -name '.*' -fprint debian/executable.files
+	find -type f -perm /111 ! -name '.*' -fprint debian/executable.files
 
 	# link these in Debian builds
 #	rm -f config.sub config.guess
