@@ -41,6 +41,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include "libps/pslib.h"
+#include "ps_error.h"
 #ifndef WIN32
 #include <unistd.h>
 #else
